.. b3j0f.utils documentation master file, created by
   sphinx-quickstart on Tue Oct 14 12:26:12 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to b3j0f.utils's documentation!
=======================================

Contents:

.. toctree::
   :maxdepth: 2

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Installation
============

pip install b3j0f.utils
